Finds optimal alignment for a discrete open srv curve to a smooth curve
find_optimal_t(srv_curve, s, q, initial_t = s, eps = 10 * .Machine$double.eps)optimal time points for q, without first value 0 and last value 1, optimal time points have the distance of the observation to the srv_curve as an attribute
srv transformation of the smooth curve, needs to be vectorized
time points for q, first has to be 0, last has to be 1
square root velocity vectors, one less than time points in s
starting value for the optimization algorithm
convergence tolerance