Finds optimal aligned time points for srv curve q to srv curve p using coordinate wise optimization.
find_optimal_t_discrete(r, p, s, q, initial_t = s, eps = 10^-3)optimal time points for q, without first value 0 and last value 1 optimal time points have the distance of the observation to the srv_curve as an attribute
time points for p, first has to be 0, last has to be 1
square root velocity vectors, one less than time points in r
time points for q, first has to be 0, last has to be 1
square root velocity vectors, one less than time points in s
starting value for the optimization algorithm
convergence tolerance