Finds optimal aligned time points for srv curve q to srv curve p using coordinate wise optimization.
find_optimal_t_discrete_closed(r, p, s, q, initial_t, eps = 10^-3)optimal time points for q, first is last -1
time points for p, first is last - 1
square root velocity vectors, one less than time points in r
time points for q, first is last - 1
square root velocity vectors, one less than time points in s
starting value for the optimization algorithm
convergence tolerance