Fits an elastic mean for open curves. Is usually called from
compute_elastic_mean.
fit_mean_closed(srv_data_curves, knots, max_iter, type, eps, pen_factor)a list
with entries
"smooth" or "polygon"
coefs srv spline coefficients of the estimated mean
spline knots
optimal parametrization
index of the starting point of the closed curve after alignment
list of data.frames with srv vectors in each row.
Usually a result of a call to get_srv_from_points
set of knots for the mean spline curve
maximal number of iterations
if "smooth" linear srv-splines are used which results in a differentiable mean curve
the algorithm stops if L2 norm of coefficients changes less
penalty factor forcing the mean to be closed if "polygon" the mean will be piecewise linear.