Learn R Programming

elasdics (version 1.1.3)

optimise_one_coord_analytic: Does optimization in one parameter direction

Description

Does optimization in one parameter direction

Usage

optimise_one_coord_analytic(t, i, r, p, s, q)

Value

optimal time points for q with respect to optimization only in the i-th coordinate direction

Arguments

t

current time points, first has to be 0, last has to be 1

i

index of t that should be updated

r

time points for p, first has to be 0, last has to be 1

p

square root velocity vectors, one less than time points in r

s

time points for q, first has to be 0, last has to be 1

q

square root velocity vectors, one less than time points in s