Learn R Programming

elasdics (version 1.1.3)

srvf_to_curve: Re-transform srv curve back to curve

Description

Re-transform srv curve back to curve

Usage

srvf_to_curve(t, srv_curve)

Value

a matrix with curve evaluations at time points t in its columns, rows correspond to coordinate directions

Arguments

t

time points at which the resulting curve shall be evaluated.

srv_curve

srv curve as a function of one parameter, needs to be vectorized.