Does optimization in one parameter direction
optimise_one_coord_analytic(t, i, r, p, s, q)optimal time points for q with respect to optimization only in the i-th coordinate direction
current time points, first has to be 0, last has to be 1
index of t that should be updated
time points for p, first has to be 0, last has to be 1
square root velocity vectors, one less than time points in r
time points for q, first has to be 0, last has to be 1
square root velocity vectors, one less than time points in s